@@ -47,7 +47,7 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
             errMsg = (("Use dynamic email configuration to send email error: "
                        "%s\n%s\nUse SmtpEmailBackend to send email") % 
                     (str(e), traceback.format_exc()))
-            logger.error(errMsg)
+            logger.warning(errMsg)
             smtp = SmtpEmailBackend()
             try:
                 r = smtp.send_messages(email_messages)
@@ -61,7 +61,7 @@ class ConfiguredEmailBackend(_ConfiguredEmailBackend):
                            "by %s as from Email") % 
                     (str(e), traceback.format_exc(), 
                      settings.DEFAULT_FROM_EMAIL))
-                logger.error(errMsg)
+                logger.warning(errMsg)
                 for message in email_messages:
                     if not message.from_email == settings.DEFAULT_FROM_EMAIL:
                         message.from_email = settings.DEFAULT_FROM_EMAIL
